@@ -817,23 +817,21 @@ on_help_about (GtkAction * action, gpointer data)
   const gchar *documenters[] = { "Timothy Musson",
     NULL
   };
-  gchar *license = games_get_license (_(APPNAME_LONG));
 
   gtk_show_about_dialog (GTK_WINDOW (app),
 			 "name", _(APPNAME_LONG),
 			 "version", VERSION,
 			 "copyright",
 			 "Copyright \xc2\xa9 1999-2008, Tim Musson and David Neary",
-			 "license", license, "comments",
-		         _("\"Four in a Row\" for GNOME, with a computer player driven by Giuliano Bertoletti's Velena Engine.\n\n\"Four in a Row\" is a part of GNOME Games."),
+			 "license-type", GTK_LICENSE_GPL_2_0, "comments",
+		         _("Connect four in a row to win.\n\nFour-in-a-row is a part of GNOME Games."),
 		         "website-label", _("GNOME Games web site"),
 			 "authors", authors, "documenters", documenters,
 			 "artists", artists, "translator-credits",
 			 _("translator-credits"),
 			 "logo-icon-name", "four-in-a-row",
 			 "website", "http://www.gnome.org/projects/gnome-games/",
-			 "wrap-license", TRUE, NULL);
-  g_free (license);
+			 NULL);
 }
 
 
@@ -1352,7 +1350,7 @@ main (int argc, char *argv[])
    * Required because the binary doesn't match the desktop file.
    * Has to be before the call to g_option_context_parse.
    */
-  g_set_prgname ("gnect");
+  g_set_prgname (APPNAME);
 
   context = g_option_context_new (NULL);
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
